@@ -44,7 +44,7 @@ class Domoticz(IPlugin):
 		idex= entity + "_" + location + "_" + on_off
 		if on_off == "allume" :
 			on_off = "on"
-		if on_off == "eteint" :
+		if on_off == "eteint" or on_off == "éteint" :
 			on_off = "off"
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
